@@ -1,41 +1,14 @@
-import datetime
 import os.path
-import re
 import tempfile
-from typing import Optional
+from typing import Optional, Pattern
 
 import pydantic
 import yaml
 from pydantic.fields import Field
 
 
-class Match(pydantic.BaseModel):
-    repository: str
-
-    @pydantic.validator("repository")
-    def repository_is_regex(cls, v):
-        try:
-            re.compile(v)
-            return v
-        except Exception as e:
-            raise ValueError(f"Unable to compile regex: {e}")
-
-    @property
-    def repository_regex(self):
-        return re.compile(self.repository)
-
-
-class Matcher(pydantic.BaseModel):
-    auto_merge_after: Optional[datetime.timedelta]
-    match: Match
-    name: str
-    packages: list[str] = []
-    pr_body: str = ""
-    pr_title: str = ""
-
-
 class Git(pydantic.BaseModel):
-    branch_name: str = "rcmt"
+    branch_prefix = "rcmt/"
     data_dir: str = os.path.join(tempfile.gettempdir(), "rcmt", "data")
     user_name: str = "rcmt"
     user_email: str = ""
@@ -43,6 +16,7 @@ class Git(pydantic.BaseModel):
 
 class Github(pydantic.BaseModel):
     access_token: str = os.getenv("RCMT_GITHUB_ACCESS_TOKEN", "")
+    base_url: str = "https://api.github.com"
 
 
 class Gitlab(pydantic.BaseModel):
@@ -65,7 +39,6 @@ class Yaml(pydantic.BaseModel):
 
 
 class Config(pydantic.BaseModel):
-    auto_merge: bool = False
     dry_run: bool = False
     git: Git = Git()
     github: Github = Github()
